This biblioteque __learn__ the peoples.

Using
------
It has got one module: __learning__
this module's call is:
    import courpr
    learning = courpr.learning.Learn()

installing
------
Enter in your bash:

    pip install courpr

Bye!